import 'package:firebase_core/firebase_core.dart';
import 'package:flutter/material.dart';
import 'package:flutter_facebook_auth/flutter_facebook_auth.dart';
import 'package:flutter/foundation.dart' show kIsWeb;
import 'package:impact/0_Impact_Global/11_Impact_Get_Device.dart';
import 'package:impact/0_Impact_Global/12_Impact_Get_IP.dart';
import 'package:impact/0_Impact_Global/13_Impact_Get_FCM.dart';
import 'package:impact/0_Impact_Global/1_Get_Data_SP.dart';
import 'package:impact/0_Impact_Global/2_Shared_Preference.dart';
import 'package:impact/0_Impact_Global/3_Set_Text_Direction.dart';
import 'package:impact/0_Impact_Global/4_Set_Theme.dart';
import 'package:impact/0_Impact_Global/5_Get_Platform.dart';
import 'package:impact/0_Impact_Global/6_Set_Lang.dart';

import '2_Loading_Enum.dart';
import '3_Lang_Enum.dart';


class ImpactInitPage extends StatefulWidget {
  var RedirectTo;
  Color? ImpactLightPrimaryColor;
  Color? ImpactLightSecondaryColor;
  Color? ImpactDarkPrimaryColor;
  Color? ImpactDarkSecondaryColor;
  ImpactSpinKitLoading? ImpactLoadingForm;
  Color? ImpactLoadingFormClr;
  double? ImpactLoadingFormSize;
  ImpactLanguages? Lang;

  ImpactInitPage({
    required this.RedirectTo        ,
    this.ImpactLightPrimaryColor    ,
    this.ImpactLightSecondaryColor  ,
    this.ImpactDarkPrimaryColor     ,
    this.ImpactDarkSecondaryColor   ,
    this.ImpactLoadingForm          ,
    this.ImpactLoadingFormClr       ,
    this.ImpactLoadingFormSize      ,
    this.Lang                       ,
  });

  @override
  State<StatefulWidget> createState() {
    return ImpactInitPageState();
  }
}

class ImpactInitPageState extends State<ImpactInitPage> {
  @override
  Widget build(BuildContext context) {

    WidgetsBinding.instance?.addPostFrameCallback((_) async {
      try{
        await Firebase.initializeApp();
      }
      catch(e){
        print("~~~~~~~~~~Impact Firebase Connecting Failed~~~~~~~~~~~~~~~");
        print("Unhandled Exception: [core/not-initialized] Firebase has not been correctly initialized. Have you added the google-services.json file to the project? ");
        print("~~~~~~~~~~Impact Firebase Connecting Failed~~~~~~~~~~~~~~~");
      }

      if(this.widget.ImpactLoadingForm!=null){
        SetImpactLoading(
            this.widget.ImpactLoadingForm!,
            (this.widget.ImpactLoadingFormSize!=null)?this.widget.ImpactLoadingFormSize!:25.0,
            (this.widget.ImpactLoadingFormClr!=null)?this.widget.ImpactLoadingFormClr!:Colors.blueGrey
        );
      }

      if(this.widget.ImpactDarkPrimaryColor != null){
        ImpactDarkPrimaryColor = this.widget.ImpactDarkPrimaryColor!;
      }

      if(this.widget.ImpactDarkSecondaryColor != null){
        ImpactDarkPrimaryColor = this.widget.ImpactDarkSecondaryColor!;
      }

      if(this.widget.ImpactLightPrimaryColor != null){
        ImpactDarkPrimaryColor = this.widget.ImpactLightPrimaryColor!;
      }

      if(this.widget.ImpactLightSecondaryColor != null){
        ImpactDarkPrimaryColor = this.widget.ImpactLightSecondaryColor!;
      }

      try{
        ImpactGetPlatform();
      }
      catch(e){
        print("~~~~~~~~~~~~Platform Exception~~~~~~~~~~~~~~");
      }

      ImpactScreenWidth  = MediaQuery.of(context).size.width;
      ImpactScreenHeight = MediaQuery.of(context).size.height;
      await ImpactGetDataSP();
      ImpactSetTheme();
      ImpactSetTextDirection();
      ImpactGetDevice();
      await ImpactGetIP();
      try{
        await ImpactGetFCM();
      }
      catch(e){
        print("~~~~~~~~~~Firebase Not Included To Get FCM~~~~~~~~~~~~");
        print(e);
        print("~~~~~~~~~~Firebase Not Included To Get FCM~~~~~~~~~~~~");
      }

      if (kIsWeb) {
        FacebookAuth.instance.webInitialize(
          appId: "1329834907365798",
          cookie: true,
          xfbml: true,
          version: "v11.0",
        );
      }

      //if(ImpactSelectedLang=="" || ImpactSelectedLang==null || ImpactSelectedLang.toString()=="null"){
        if(this.widget.Lang!=null){
          if(this.widget.Lang!.index==0){
            ImpactSelectedLang = "English";
          }
          else if(this.widget.Lang!.index==1){
            ImpactSelectedLang = "Arabic";
          }
          else if(this.widget.Lang!.index==2){
            ImpactSelectedLang = "Spanish";
          }
          else if(this.widget.Lang!.index==3){
            ImpactSelectedLang = "French";
          }
          else if(this.widget.Lang!.index==4){
            ImpactSelectedLang = "Hindi";
          }
        // }
        // else {
        //   ImpactSelectedLang = "English";
        // }
      }
      ImpactSetLang();


      Navigator.of(context).pushReplacement(MaterialPageRoute(builder:(context)=>this.widget.RedirectTo));
    });


    return Scaffold(
      body:Center(
        child:CircularProgressIndicator(),
      ),
    );
  }

}